==> srecord-1.60.tar.gz: srecord-1.60/srecord/srecord.h <==
//
// srecord - Manipulate EPROM load files
// Copyright (C) 2010-2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#ifndef SRECORD_SRECORD_H
#define SRECORD_SRECORD_H

#include <srecord/input.h>
#include <srecord/input/catenate.h>
#include <srecord/input/file.h>
#include <srecord/input/file/aomf.h>
#include <srecord/input/file/ascii_hex.h>
#include <srecord/input/file/atmel_generic.h>
#include <srecord/input/file/binary.h>
#include <srecord/input/file/brecord.h>
#include <srecord/input/file/cosmac.h>
#include <srecord/input/file/dec_binary.h>
#include <srecord/input/file/emon52.h>
#include <srecord/input/file/fairchild.h>
#include <srecord/input/file/fastload.h>
#include <srecord/input/file/formatted_binary.h>
#include <srecord/input/file/four_packed_code.h>
#include <srecord/input/file/intel.h>
#include <srecord/input/file/intel16.h>
#include <srecord/input/file/mif.h>
#include <srecord/input/file/mips_flash.h>
#include <srecord/input/file/mos_tech.h>
#include <srecord/input/file/msbin.h>
#include <srecord/input/file/needham.h>
#include <srecord/input/file/os65v.h>
#include <srecord/input/file/ppb.h>
#include <srecord/input/file/ppx.h>
#include <srecord/input/file/signetics.h>
#include <srecord/input/file/spasm.h>
#include <srecord/input/file/spectrum.h>
#include <srecord/input/file/srecord.h>
#include <srecord/input/file/stewie.h>
#include <srecord/input/file/tektronix.h>
#include <srecord/input/file/tektronix_extended.h>
#include <srecord/input/file/ti_tagged.h>
#include <srecord/input/file/ti_tagged_16.h>
#include <srecord/input/file/ti_txt.h>
#include <srecord/input/file/trs80.h>
#include <srecord/input/file/vmem.h>
#include <srecord/input/file/wilson.h>
#include <srecord/input/filter.h>
#include <srecord/input/filter/and.h>
#include <srecord/input/filter/bitrev.h>
#include <srecord/input/filter/byte_swap.h>
#include <srecord/input/filter/checksum.h>
#include <srecord/input/filter/checksum/bitnot.h>
#include <srecord/input/filter/checksum/negative.h>
#include <srecord/input/filter/checksum/positive.h>
#include <srecord/input/filter/crop.h>
#include <srecord/input/filter/fill.h>
#include <srecord/input/filter/interval.h>
#include <srecord/input/filter/interval/length.h>
#include <srecord/input/filter/interval/maximum.h>
#include <srecord/input/filter/interval/minimum.h>
#include <srecord/input/filter/message.h>
#include <srecord/input/filter/message/adler16.h>
#include <srecord/input/filter/message/adler32.h>
#include <srecord/input/filter/message/crc16.h>
#include <srecord/input/filter/message/crc32.h>
#include <srecord/input/filter/message/fletcher16.h>
#include <srecord/input/filter/message/fletcher32.h>
#include <srecord/input/filter/message/gcrypt.h>
#include <srecord/input/filter/not.h>
#include <srecord/input/filter/offset.h>
#include <srecord/input/filter/or.h>
#include <srecord/input/filter/random_fill.h>
#include <srecord/input/filter/sequence.h>
#include <srecord/input/filter/split.h>
#include <srecord/input/filter/unfill.h>
#include <srecord/input/filter/unsplit.h>
#include <srecord/input/filter/xor.h>
#include <srecord/input/generator.h>
#include <srecord/input/generator/constant.h>
#include <srecord/input/generator/random.h>
#include <srecord/input/generator/repeat.h>
#include <srecord/memory.h>
#include <srecord/memory/chunk.h>
#include <srecord/memory/walker.h>
#include <srecord/memory/walker/compare.h>
#include <srecord/memory/walker/continuity.h>
#include <srecord/memory/walker/gcrypt.h>
#include <srecord/memory/walker/writer.h>
#include <srecord/output.h>
#include <srecord/output/file.h>
#include <srecord/output/file/aomf.h>
#include <srecord/output/file/ascii_hex.h>
#include <srecord/output/file/asm.h>
#include <srecord/output/file/atmel_generic.h>
#include <srecord/output/file/basic.h>
#include <srecord/output/file/binary.h>
#include <srecord/output/file/brecord.h>
#include <srecord/output/file/c.h>
#include <srecord/output/file/cosmac.h>
#include <srecord/output/file/dec_binary.h>
#include <srecord/output/file/emon52.h>
#include <srecord/output/file/fairchild.h>
#include <srecord/output/file/fastload.h>
#include <srecord/output/file/formatted_binary.h>
#include <srecord/output/file/forth.h>
#include <srecord/output/file/four_packed_code.h>
#include <srecord/output/file/hexdump.h>
#include <srecord/output/file/intel.h>
#include <srecord/output/file/intel16.h>
#include <srecord/output/file/mif.h>
#include <srecord/output/file/mips_flash.h>
#include <srecord/output/file/mos_tech.h>
#include <srecord/output/file/msbin.h>
#include <srecord/output/file/needham.h>
#include <srecord/output/file/os65v.h>
#include <srecord/output/file/ppb.h>
#include <srecord/output/file/ppx.h>
#include <srecord/output/file/signetics.h>
#include <srecord/output/file/spasm.h>
#include <srecord/output/file/spectrum.h>
#include <srecord/output/file/srecord.h>
#include <srecord/output/file/stewie.h>
#include <srecord/output/file/tektronix.h>
#include <srecord/output/file/tektronix_extended.h>
#include <srecord/output/file/ti_tagged.h>
#include <srecord/output/file/ti_tagged_16.h>
#include <srecord/output/file/ti_txt.h>
#include <srecord/output/file/trs80.h>
#include <srecord/output/file/vhdl.h>
#include <srecord/output/file/vmem.h>
#include <srecord/output/file/wilson.h>
#include <srecord/quit.h>
#include <srecord/quit/exception.h>
#include <srecord/quit/normal.h>
#include <srecord/quit/prefix.h>
#include <srecord/record.h>

// vim: set ts=8 sw=4 et :
#endif // SRECORD_SRECORD_H

==> srecord_1.64.orig.tar.gz: srecord-1.64/srecord/srecord.h <==
//
// srecord - Manipulate EPROM load files
// Copyright (C) 2010-2013 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#ifndef SRECORD_SRECORD_H
#define SRECORD_SRECORD_H

#include <srecord/input.h>
#include <srecord/input/catenate.h>
#include <srecord/input/file.h>
#include <srecord/input/file/aomf.h>
#include <srecord/input/file/ascii_hex.h>
#include <srecord/input/file/atmel_generic.h>
#include <srecord/input/file/binary.h>
#include <srecord/input/file/brecord.h>
#include <srecord/input/file/coe.h>
#include <srecord/input/file/cosmac.h>
#include <srecord/input/file/dec_binary.h>
#include <srecord/input/file/emon52.h>
#include <srecord/input/file/fairchild.h>
#include <srecord/input/file/fastload.h>
#include <srecord/input/file/formatted_binary.h>
#include <srecord/input/file/four_packed_code.h>
#include <srecord/input/file/intel.h>
#include <srecord/input/file/logisim.h>
#include <srecord/input/file/mem.h>
#include <srecord/input/file/mif.h>
#include <srecord/input/file/mips_flash.h>
#include <srecord/input/file/mos_tech.h>
#include <srecord/input/file/msbin.h>
#include <srecord/input/file/needham.h>
#include <srecord/input/file/os65v.h>
#include <srecord/input/file/ppb.h>
#include <srecord/input/file/ppx.h>
#include <srecord/input/file/signetics.h>
#include <srecord/input/file/spasm.h>
#include <srecord/input/file/spectrum.h>
#include <srecord/input/file/srecord.h>
#include <srecord/input/file/stewie.h>
#include <srecord/input/file/tektronix.h>
#include <srecord/input/file/tektronix_extended.h>
#include <srecord/input/file/ti_tagged.h>
#include <srecord/input/file/ti_tagged_16.h>
#include <srecord/input/file/ti_txt.h>
#include <srecord/input/file/trs80.h>
#include <srecord/input/file/vmem.h>
#include <srecord/input/file/wilson.h>
#include <srecord/input/filter.h>
#include <srecord/input/filter/and.h>
#include <srecord/input/filter/bitrev.h>
#include <srecord/input/filter/byte_swap.h>
#include <srecord/input/filter/checksum.h>
#include <srecord/input/filter/checksum/bitnot.h>
#include <srecord/input/filter/checksum/negative.h>
#include <srecord/input/filter/checksum/positive.h>
#include <srecord/input/filter/crop.h>
#include <srecord/input/filter/fill.h>
#include <srecord/input/filter/interval.h>
#include <srecord/input/filter/interval/length.h>
#include <srecord/input/filter/interval/maximum.h>
#include <srecord/input/filter/interval/minimum.h>
#include <srecord/input/filter/message.h>
#include <srecord/input/filter/message/adler16.h>
#include <srecord/input/filter/message/adler32.h>
#include <srecord/input/filter/message/crc16.h>
#include <srecord/input/filter/message/crc32.h>
#include <srecord/input/filter/message/fletcher16.h>
#include <srecord/input/filter/message/fletcher32.h>
#include <srecord/input/filter/message/gcrypt.h>
#include <srecord/input/filter/not.h>
#include <srecord/input/filter/offset.h>
#include <srecord/input/filter/or.h>
#include <srecord/input/filter/random_fill.h>
#include <srecord/input/filter/sequence.h>
#include <srecord/input/filter/split.h>
#include <srecord/input/filter/unfill.h>
#include <srecord/input/filter/unsplit.h>
#include <srecord/input/filter/xor.h>
#include <srecord/input/generator.h>
#include <srecord/input/generator/constant.h>
#include <srecord/input/generator/random.h>
#include <srecord/input/generator/repeat.h>
#include <srecord/memory.h>
#include <srecord/memory/chunk.h>
#include <srecord/memory/walker.h>
#include <srecord/memory/walker/compare.h>
#include <srecord/memory/walker/continuity.h>
#include <srecord/memory/walker/gcrypt.h>
#include <srecord/memory/walker/writer.h>
#include <srecord/output.h>
#include <srecord/output/file.h>
#include <srecord/output/file/aomf.h>
#include <srecord/output/file/ascii_hex.h>
#include <srecord/output/file/asm.h>
#include <srecord/output/file/atmel_generic.h>
#include <srecord/output/file/basic.h>
#include <srecord/output/file/binary.h>
#include <srecord/output/file/brecord.h>
#include <srecord/output/file/c.h>
#include <srecord/output/file/cosmac.h>
#include <srecord/output/file/dec_binary.h>
#include <srecord/output/file/emon52.h>
#include <srecord/output/file/fairchild.h>
#include <srecord/output/file/fastload.h>
#include <srecord/output/file/formatted_binary.h>
#include <srecord/output/file/forth.h>
#include <srecord/output/file/four_packed_code.h>
#include <srecord/output/file/hexdump.h>
#include <srecord/output/file/intel.h>
#include <srecord/output/file/intel16.h>
#include <srecord/output/file/logisim.h>
#include <srecord/output/file/mif.h>
#include <srecord/output/file/mips_flash.h>
#include <srecord/output/file/mos_tech.h>
#include <srecord/output/file/msbin.h>
#include <srecord/output/file/needham.h>
#include <srecord/output/file/os65v.h>
#include <srecord/output/file/ppb.h>
#include <srecord/output/file/ppx.h>
#include <srecord/output/file/signetics.h>
#include <srecord/output/file/spasm.h>
#include <srecord/output/file/spectrum.h>
#include <srecord/output/file/srecord.h>
#include <srecord/output/file/stewie.h>
#include <srecord/output/file/tektronix.h>
#include <srecord/output/file/tektronix_extended.h>
#include <srecord/output/file/ti_tagged.h>
#include <srecord/output/file/ti_tagged_16.h>
#include <srecord/output/file/ti_txt.h>
#include <srecord/output/file/trs80.h>
#include <srecord/output/file/vhdl.h>
#include <srecord/output/file/vmem.h>
#include <srecord/output/file/wilson.h>
#include <srecord/quit.h>
#include <srecord/quit/exception.h>
#include <srecord/quit/normal.h>
#include <srecord/quit/prefix.h>
#include <srecord/record.h>

// vim: set ts=8 sw=4 et :
#endif // SRECORD_SRECORD_H
